clear;clc;close all

%                       ***** PROGRAM 1.1 *****                            

% COMPARISON OF THE MOTION OF A STEEL SPHERE  DROPPED IN AIR WITH THAT IN
% VACUUM, BASED ON FOURTH-ORDER RUNGE-KUTTA METHOD
% Reference: Computational Fluid Mechanics by Example (Biringen and Chow; Wiley 2011)

clc;
clear all;
format short e;

global A B C D NU

% ***** SPECIFY DATA *****

T0 = 0.;
Z0 = 0.;
V0 = 0.;
RHO = 8000.0;
RHOF = 1.22;
G = 9.8;
H = 0.1;
TMAX = 10.0;
RHOBAR = RHOF/RHO;
NU = 0.0000149;
A = 1.+RHOBAR/2.;
B = (1.-RHOBAR)*G;
D = 0.01;
C = 3.*RHOBAR/(4.*D);


% ***** INITIALIZE THE PROBLEM *****

T = T0;
Z = Z0;
V = V0;
RE = V*D/NU;


% ***** COMPUTE POSITION AND VELOCITY IN VACUUM, AND PRINT DATA *****

disp('    T          Z(IN VACUUM)      Z       V(IN VACUUM)      V            RE');
disp('  (SEC)             (M)         (M)         (M/SEC)     (M/SEC)           ');
N=1;
while (T<=TMAX)
    
    ZV = Z0 + V0*T + G*T*T/2.;
    VV = V0 + G*T;
    disp([T,ZV,Z,VV,V,RE]);


% ***** RUNGE-KUTTA METHOD *****

    D1Z = H*V;
    D1V = H*F(V);
    D2Z = H*(V + D1V/2.);
    D2V = H*F(V+D1V/2.);
    D3Z = H*(V + D2V/2.);
    D3V = H*F(V+D2V/2.);
    D4Z = H*(V + D3V);
    D4V = H*F(V+D3V);
    T = T + H;
    N=N+1;
    
    Z = Z + (D1Z + 2.*D2Z + 2.*D3Z + D4Z)/6.;
    V = V + (D1V + 2.*D2V + 2.*D3V + D4V)/6.;
    RE = V*D/NU;
    
    %save the data for plot
    t(N)=T;
    
    % vacuum
    zv(N)=ZV;
    vv(N)=VV;

    % in air
    z(N)=Z;
    v(N)=V;

% ***** REPEAT THE COMPUTATION IF T<=TMAX, OTHERWISE STOP *****

end

% Plot locations
figure
plot(t,zv,'-g','linewidth',2);
hold on
plot(t,z,'-r','linewidth',2);
hold off
xlabel('t (s)','FontSize',30);
ylabel('z (m)','FontSize',30);
grid on
title('Sphere diameter, D = 0.01','FontSize',20);
legend('In Vacuum','In Air','location','NorthWest');
axis tight
set(gca,'LineWidth',1)
set(gca,'TickDir','out')
set(gca,'FontSize',16)   

% Plot velocities
figure
plot(t,vv,'-g','linewidth',2);
hold on
plot(t,v,'-r','linewidth',2);
hold off
xlabel('t (s)','FontSize',30);
ylabel('v (m/s)','FontSize',30);
grid on
title('Sphere diameter, D = 0.01','FontSize',20);
legend('In Vacuum','In Air','location','NorthWest');
axis tight
set(gca,'LineWidth',1)
set(gca,'TickDir','out')
set(gca,'FontSize',16)   
